"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthenticationServiceComponent = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const loopback4_helmet_1 = require("loopback4-helmet");
const controllers_1 = require("./controllers");
const keys_1 = require("./keys");
const models_1 = require("./models");
const auth_1 = require("./modules/auth");
const repositories_1 = require("./repositories");
const sequence_1 = require("./sequence");
const keycloak_verify_provider_1 = require("./modules/auth/providers/keycloak-verify.provider");
const providers_1 = require("./providers");
const keycloak_signup_provider_1 = require("./providers/keycloak-signup.provider");
let AuthenticationServiceComponent = class AuthenticationServiceComponent {
    constructor(application, authConfig) {
        var _a;
        this.application = application;
        this.authConfig = authConfig;
        this.providers = {};
        this.bindings = [];
        this.bindings = [];
        this.providers = {};
        // Mount core component
        this.application.component(core_2.CoreComponent);
        // Mount authentication component
        this.setupAuthenticationComponent();
        // Mount authorization component
        this.setupAuthorizationComponent();
        this.application.api({
            openapi: '3.0.0',
            info: {
                title: 'Authentication Service',
                version: '1.0.0',
            },
            paths: {},
            components: {
                securitySchemes: core_2.SECURITY_SCHEME_SPEC,
            },
            servers: [{ url: '/' }],
        });
        // Mount Helmet component
        this.application.component(loopback4_helmet_1.Loopback4HelmetComponent);
        this.bindings.push(core_1.Binding.bind(loopback4_helmet_1.HelmetSecurityBindings.CONFIG).to({
            referrerPolicy: {
                policy: 'same-origin',
            },
            contentSecurityPolicy: {
                directives: {
                    frameSrc: ["'self'"],
                },
            },
        }));
        // Mount default sequence if needed
        if (!((_a = this.authConfig) === null || _a === void 0 ? void 0 : _a.useCustomSequence)) {
            // Mount default sequence if needed
            this.setupSequence();
        }
        this.repositories = repositories_1.repositories;
        this.models = models_1.models;
        this.controllers = controllers_1.controllers;
    }
    /**
     * Setup ServiceSequence by default if no other sequnce provided
     *
     * @param bindings Binding array
     */
    setupSequence() {
        this.application.sequence(sequence_1.MySequence);
    }
    setupAuthenticationComponent() {
        // Add authentication component
        this.application.component(loopback4_authentication_1.AuthenticationComponent);
        // Customize authentication verify handlers
        this.providers[loopback4_authentication_1.Strategies.Passport.OAUTH2_CLIENT_PASSWORD_VERIFIER.key] = auth_1.ClientPasswordVerifyProvider;
        this.providers[loopback4_authentication_1.Strategies.Passport.LOCAL_PASSWORD_VERIFIER.key] = auth_1.LocalPasswordVerifyProvider;
        this.providers[loopback4_authentication_1.Strategies.Passport.BEARER_TOKEN_VERIFIER.key] = auth_1.BearerTokenVerifyProvider;
        this.providers[loopback4_authentication_1.Strategies.Passport.RESOURCE_OWNER_PASSWORD_VERIFIER.key] = auth_1.ResourceOwnerVerifyProvider;
        this.providers[loopback4_authentication_1.Strategies.Passport.GOOGLE_OAUTH2_VERIFIER.key] = auth_1.GoogleOauth2VerifyProvider;
        this.providers[loopback4_authentication_1.Strategies.Passport.KEYCLOAK_VERIFIER.key] = keycloak_verify_provider_1.KeycloakVerifyProvider;
        this.providers[providers_1.SignUpBindings.KEYCLOAK_SIGN_UP_PROVIDER.key] = keycloak_signup_provider_1.KeyCloakSignupProvider;
        this.providers[providers_1.SignUpBindings.GOOGLE_SIGN_UP_PROVIDER.key] = providers_1.GoogleOauth2SignupProvider;
        this.providers[providers_1.VerifyBindings.KEYCLOAK_PRE_VERIFY_PROVIDER.key] = providers_1.KeyCloakPreVerifyProvider;
        this.providers[providers_1.VerifyBindings.KEYCLOAK_POST_VERIFY_PROVIDER.key] = providers_1.KeyCloakPostVerifyProvider;
        this.providers[providers_1.VerifyBindings.GOOGLE_PRE_VERIFY_PROVIDER.key] = providers_1.GooglePreVerifyProvider;
        this.providers[providers_1.VerifyBindings.GOOGLE_POST_VERIFY_PROVIDER.key] = providers_1.GooglePostVerifyProvider;
    }
    setupAuthorizationComponent() {
        // Add authorization component
        this.application.bind(loopback4_authorization_1.AuthorizationBindings.CONFIG).to({
            allowAlwaysPaths: ['/explorer'],
        });
        this.application.component(loopback4_authorization_1.AuthorizationComponent);
    }
};
AuthenticationServiceComponent = tslib_1.__decorate([
    tslib_1.__param(0, core_1.inject(core_1.CoreBindings.APPLICATION_INSTANCE)),
    tslib_1.__param(1, core_1.inject(keys_1.AuthServiceBindings.Config, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [rest_1.RestApplication, Object])
], AuthenticationServiceComponent);
exports.AuthenticationServiceComponent = AuthenticationServiceComponent;
//# sourceMappingURL=component.js.map