"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BearerTokenVerifyProvider = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const jsonwebtoken_1 = require("jsonwebtoken");
const moment_timezone_1 = tslib_1.__importDefault(require("moment-timezone"));
const repositories_1 = require("../../../repositories");
let BearerTokenVerifyProvider = class BearerTokenVerifyProvider {
    constructor(revokedTokenRepository, logger) {
        this.revokedTokenRepository = revokedTokenRepository;
        this.logger = logger;
    }
    value() {
        return async (token, req) => {
            const isRevoked = await this.revokedTokenRepository.get(token);
            if (isRevoked === null || isRevoked === void 0 ? void 0 : isRevoked.token) {
                throw new rest_1.HttpErrors.Unauthorized("TokenRevoked" /* TokenRevoked */);
            }
            let user;
            try {
                user = jsonwebtoken_1.verify(token, process.env.JWT_SECRET, {
                    issuer: process.env.JWT_ISSUER,
                });
            }
            catch (error) {
                this.logger.error(JSON.stringify(error));
                throw new rest_1.HttpErrors.Unauthorized('TokenExpired');
            }
            if (user.passwordExpiryTime &&
                moment_timezone_1.default().isSameOrAfter(moment_timezone_1.default(user.passwordExpiryTime))) {
                throw new rest_1.HttpErrors.Unauthorized("PasswordExpiryError" /* PasswordExpiryError */);
            }
            return user;
        };
    }
};
BearerTokenVerifyProvider = tslib_1.__decorate([
    tslib_1.__param(0, repository_1.repository(repositories_1.RevokedTokenRepository)),
    tslib_1.__param(1, context_1.inject(core_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.RevokedTokenRepository, Object])
], BearerTokenVerifyProvider);
exports.BearerTokenVerifyProvider = BearerTokenVerifyProvider;
//# sourceMappingURL=bearer-token-verify.provider.js.map